==> jc-1.4.0.tar.gz: java/awt/TextField__24AccessibleAWTTextField.h <==
// public class java.awt.TextField$AccessibleAWTTextField

// class file dependencies
// @dep_class 61b24c22f38bff85 java_awt_Component__24AccessibleAWTComponent
// @dep_class 6e8c54c389951134 java_awt_TextComponent__24AccessibleAWTTextComponent
// @dep_class 70bac29091fde902 java_awt_TextField__24AccessibleAWTTextField
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_TextComponent__24AccessibleAWTTextComponent

#include "java/awt/TextComponent__24AccessibleAWTTextComponent.h"

#ifndef _JC_java_awt_TextField__24AccessibleAWTTextField_H_
#define _JC_java_awt_TextField__24AccessibleAWTTextField_H_

// Forward structure declarations
struct _jc_java_awt_TextField$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$sub_refs	_jc_java_awt_TextField__24AccessibleAWTTextField$sub_refs;
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$sub_nonrefs	_jc_java_awt_TextField__24AccessibleAWTTextField$sub_nonrefs;
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$refs	_jc_java_awt_TextField__24AccessibleAWTTextField$refs;
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$nonrefs	_jc_java_awt_TextField__24AccessibleAWTTextField$nonrefs;
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$object	_jc_java_awt_TextField__24AccessibleAWTTextField$object;

typedef const struct _jc_java_awt_TextField__24AccessibleAWTTextField$vmethods	_jc_java_awt_TextField__24AccessibleAWTTextField$vmethods;
typedef const struct _jc_java_awt_TextField__24AccessibleAWTTextField$vtable	_jc_java_awt_TextField__24AccessibleAWTTextField$vtable;
typedef const struct _jc_java_awt_TextField__24AccessibleAWTTextField$vtype	_jc_java_awt_TextField__24AccessibleAWTTextField$vtype;

// Constructors
extern void _jc_java_awt_TextField__24AccessibleAWTTextField$method$_init$6b74252823b32409(_jc_env *, struct _jc_java_awt_TextField__24AccessibleAWTTextField$object *, struct _jc_java_awt_TextField$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_TextField__24AccessibleAWTTextField$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_TextField__24AccessibleAWTTextField$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_TextField__24AccessibleAWTTextField$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_awt_TextField__24AccessibleAWTTextField$vmethods {
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_TextField__24AccessibleAWTTextField$object *);
};

// Vtable
struct _jc_java_awt_TextField__24AccessibleAWTTextField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_TextComponent__24AccessibleAWTTextComponent$vmethods	java_awt_TextComponent__24AccessibleAWTTextComponent;
	_jc_java_awt_TextField__24AccessibleAWTTextField$vmethods	java_awt_TextField__24AccessibleAWTTextField;
};

// Vtype
struct _jc_java_awt_TextField__24AccessibleAWTTextField$vtype {
	_jc_type			type;
	_jc_java_awt_TextField__24AccessibleAWTTextField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_TextField__24AccessibleAWTTextField$sub_refs {
	struct _jc_java_awt_TextField$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_TextField__24AccessibleAWTTextField$refs {
    _jc_java_awt_TextField__24AccessibleAWTTextField$sub_refs	java_awt_TextField__24AccessibleAWTTextField;
    _jc_java_awt_TextComponent__24AccessibleAWTTextComponent$sub_refs	java_awt_TextComponent__24AccessibleAWTTextComponent;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_TextField__24AccessibleAWTTextField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_TextField__24AccessibleAWTTextField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_TextComponent__24AccessibleAWTTextComponent$sub_nonrefs	java_awt_TextComponent__24AccessibleAWTTextComponent;
    _jc_java_awt_TextField__24AccessibleAWTTextField$sub_nonrefs	java_awt_TextField__24AccessibleAWTTextField;
};

// Object instance structure
struct _jc_java_awt_TextField__24AccessibleAWTTextField$object {
	_jc_java_awt_TextField__24AccessibleAWTTextField$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_TextField__24AccessibleAWTTextField$vtype	*vtype;
	_jc_java_awt_TextField__24AccessibleAWTTextField$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_TextField__24AccessibleAWTTextField$vtype _jc_java_awt_TextField__24AccessibleAWTTextField$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_TextField__24AccessibleAWTTextField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_TextField__24AccessibleAWTTextField$class_object;

#endif	/* _JC_java_awt_TextField__24AccessibleAWTTextField_H_ */

==> jc-1.4.5.tar.gz: java/awt/TextField__24AccessibleAWTTextField.h <==
// public class java.awt.TextField$AccessibleAWTTextField

// class file dependencies
// @dep_class e1ad6f3c35669e42 java_awt_Component__24AccessibleAWTComponent
// @dep_class 620f05f6023d921c java_awt_TextComponent__24AccessibleAWTTextComponent
// @dep_class 70bac29091fde902 java_awt_TextField__24AccessibleAWTTextField
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_TextComponent__24AccessibleAWTTextComponent

#include "java/awt/TextComponent__24AccessibleAWTTextComponent.h"

#ifndef _JC_java_awt_TextField__24AccessibleAWTTextField_H_
#define _JC_java_awt_TextField__24AccessibleAWTTextField_H_

// Forward structure declarations
struct _jc_java_awt_TextField$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_accessibility_AccessibleStateSet$object;

// Typedefs
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$sub_refs	_jc_java_awt_TextField__24AccessibleAWTTextField$sub_refs;
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$sub_nonrefs	_jc_java_awt_TextField__24AccessibleAWTTextField$sub_nonrefs;
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$refs	_jc_java_awt_TextField__24AccessibleAWTTextField$refs;
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$nonrefs	_jc_java_awt_TextField__24AccessibleAWTTextField$nonrefs;
typedef struct _jc_java_awt_TextField__24AccessibleAWTTextField$object	_jc_java_awt_TextField__24AccessibleAWTTextField$object;

typedef const struct _jc_java_awt_TextField__24AccessibleAWTTextField$vmethods	_jc_java_awt_TextField__24AccessibleAWTTextField$vmethods;
typedef const struct _jc_java_awt_TextField__24AccessibleAWTTextField$vtable	_jc_java_awt_TextField__24AccessibleAWTTextField$vtable;
typedef const struct _jc_java_awt_TextField__24AccessibleAWTTextField$vtype	_jc_java_awt_TextField__24AccessibleAWTTextField$vtype;

// Constructors
extern void _jc_java_awt_TextField__24AccessibleAWTTextField$method$_init$6b74252823b32409(_jc_env *, struct _jc_java_awt_TextField__24AccessibleAWTTextField$object *, struct _jc_java_awt_TextField$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleStateSet$object *_jc_java_awt_TextField__24AccessibleAWTTextField$method$getAccessibleStateSet$1a4e9ea496bda550(_jc_env *, struct _jc_java_awt_TextField__24AccessibleAWTTextField$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_TextField__24AccessibleAWTTextField$method_info$getAccessibleStateSet$1a4e9ea496bda550;

// Virtual methods structure
struct _jc_java_awt_TextField__24AccessibleAWTTextField$vmethods {
	struct _jc_javax_accessibility_AccessibleStateSet$object	*(*getAccessibleStateSet$1a4e9ea496bda550)(_jc_env *, struct _jc_java_awt_TextField__24AccessibleAWTTextField$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_TextField__24AccessibleAWTTextField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_Component__24AccessibleAWTComponent$vmethods	java_awt_Component__24AccessibleAWTComponent;
	_jc_java_awt_TextComponent__24AccessibleAWTTextComponent$vmethods	java_awt_TextComponent__24AccessibleAWTTextComponent;
	_jc_java_awt_TextField__24AccessibleAWTTextField$vmethods	java_awt_TextField__24AccessibleAWTTextField;
};

// Vtype
struct _jc_java_awt_TextField__24AccessibleAWTTextField$vtype {
	_jc_type			type;
	_jc_java_awt_TextField__24AccessibleAWTTextField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_TextField__24AccessibleAWTTextField$sub_refs {
	struct _jc_java_awt_TextField$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_TextField__24AccessibleAWTTextField$refs {
    _jc_java_awt_TextField__24AccessibleAWTTextField$sub_refs	java_awt_TextField__24AccessibleAWTTextField;
    _jc_java_awt_TextComponent__24AccessibleAWTTextComponent$sub_refs	java_awt_TextComponent__24AccessibleAWTTextComponent;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_refs	java_awt_Component__24AccessibleAWTComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_TextField__24AccessibleAWTTextField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_TextField__24AccessibleAWTTextField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_Component__24AccessibleAWTComponent$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent;
    _jc_java_awt_TextComponent__24AccessibleAWTTextComponent$sub_nonrefs	java_awt_TextComponent__24AccessibleAWTTextComponent;
    _jc_java_awt_TextField__24AccessibleAWTTextField$sub_nonrefs	java_awt_TextField__24AccessibleAWTTextField;
};

// Object instance structure
struct _jc_java_awt_TextField__24AccessibleAWTTextField$object {
	_jc_java_awt_TextField__24AccessibleAWTTextField$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_TextField__24AccessibleAWTTextField$vtype	*vtype;
	_jc_java_awt_TextField__24AccessibleAWTTextField$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_TextField__24AccessibleAWTTextField$vtype _jc_java_awt_TextField__24AccessibleAWTTextField$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_TextField__24AccessibleAWTTextField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_TextField__24AccessibleAWTTextField$class_object;

#endif	/* _JC_java_awt_TextField__24AccessibleAWTTextField_H_ */
